# intel-compute-runtime.spec

# Define the base name of the package
%define _name intel-compute-runtime
# Define the version. This should be updated for new releases.
# The version 24.35.30872.32 is derived from search results suggesting it's the latest in the 24.35 series for legacy platforms.
%define version 24.35.30872.32
# Define the release number for the RPM. Increment this for new builds of the same upstream version.
%define release 1%{?dist}
# Define the commit hash or tag if building directly from a specific commit/tag on a branch.
# For COPR auto-builds, if you want to track the latest commit on a branch (e.g., 'releases/24.35'),
# you would typically set 'commit' to the actual commit hash or a symbolic ref like 'releases/24.35'.
# For this .spec, we assume the version string corresponds to a GitHub release tag,
# which is a common way to fetch stable source code for auto-builds.
%define commit %{version}

Summary: Intel(R) Graphics Compute Runtime for oneAPI Level Zero and OpenCL(TM) Driver
Name: %{_name}
Version: %{version}
Release: %{release}
License: MIT
URL: https://github.com/intel/compute-runtime
# Source for COPR auto-builds often uses the archive directly.
# If tracking a specific branch head (not a release tag), 'commit' would be the branch name (e.g., 'releases/24.35')
# and the URL would be: https://github.com/intel/compute-runtime/archive/%{commit}.tar.gz
Source0: %{url}/archive/refs/tags/%{commit}.tar.gz#/%{_name}-%{version}.tar.gz

BuildRequires: cmake
BuildRequires: gcc-c++
BuildRequires: pkgconfig(libdrm)
BuildRequires: pkgconfig(wayland-protocols)
BuildRequires: systemd-rpm-macros
BuildRequires: json-c-devel
BuildRequires: libxml2-devel
BuildRequires: llvm-devel >= 15.0.0
BuildRequires: clang-devel >= 15.0.0
BuildRequires: spirv-headers-devel
BuildRequires: spirv-tools-devel
BuildRequires: opencl-headers
BuildRequires: level-zero-headers
BuildRequires: intel-gmmlib-devel
BuildRequires: intel-graphics-compiler-devel
BuildRequires: libva-devel
BuildRequires: libigsc-devel
BuildRequires: valgrind-devel

Requires: opencl-filesystem
Requires: level-zero
Requires: intel-gmmlib
Requires: intel-graphics-compiler

%description
The Intel(R) Graphics Compute Runtime for oneAPI Level Zero and OpenCL(TM) Driver
is an open source project providing compute API support (Level Zero, OpenCL)
for Intel graphics hardware architectures (HD Graphics, Xe).

This package provides the necessary runtime components for Intel GPUs.

%prep
%autosetup -n compute-runtime-%{commit}

%build
%cmake \
    -DNEO_UNIT_TESTS=OFF \
    -DNEO_ENABLE_RELEASE_BUILD=ON \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DNEO_ENABLE_OPENCL=ON \
    -DNEO_ENABLE_LEVEL_ZERO=ON \
    -DNEO_BUILD_WITH_OCLOC=ON \
    -DNEO_BUILD_WITH_SHARED_LIB=ON \
    -DNEO_BUILD_TESTS=OFF \
    -DNEO_BUILD_DEBUG_RUNTIME=OFF

%cmake_build

%install
%cmake_install

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license LICENSE
%{_bindir}/ocloc
%{_libdir}/libigdrcl.so*
%{_libdir}/libocloc.so*
%{_libdir}/libocloc-frontend.so*
%{_libdir}/libze_intel_gpu.so*
%{_libdir}/libocloc.so.%{version}
%{_libdir}/libze_intel_gpu.so.%{version}
%{_libdir}/pkgconfig/libocloc.pc
%{_libdir}/pkgconfig/libze_intel_gpu.pc
%{_datadir}/opencl/vendors/intel.icd
%{_datadir}/level-zero/intel_gpu.json
# Include documentation and any other relevant files if available in the build.
# For example: %{_docdir}/%{_name}/README.md

%changelog
* Fri Jun 21 2025 Your Name <youremail@example.com> - %{version}-1
- Initial COPR package for Intel Compute Runtime branch 24.35
